@@ -32,6 +32,7 @@
 #include <string.h>
 
 enum {
+    CMD_NONE,
     CMD_MOUNT_OR_PLAY,
     CMD_UNMOUNT,
     CMD_EJECT
@@ -40,7 +41,7 @@ enum {
 #define GCONF_ROOT_AUTOPLAY  "/desktop/gnome/volume_manager/"
 
 /* type registration boilerplate code */
-G_DEFINE_TYPE(DriveButton, drive_button, GTK_TYPE_BUTTON);
+G_DEFINE_TYPE(DriveButton, drive_button, GTK_TYPE_BUTTON)
 
 static void     drive_button_set_drive    (DriveButton    *self,
 				           GnomeVFSDrive  *drive);
@@ -302,7 +303,7 @@ drive_button_update (gpointer user_data)
     GtkIconTheme *icon_theme;
     char *icon_name;
     int width, height;
-    GdkPixbuf *pixbuf;
+    GdkPixbuf *pixbuf, *scaled;
     GtkRequisition button_req, image_req;
 
     g_return_val_if_fail (DRIVE_IS_BUTTON (user_data), FALSE);
@@ -376,6 +377,12 @@ drive_button_update (gpointer user_data)
     if (!pixbuf)
 	return FALSE;
 
+    scaled = gdk_pixbuf_scale_simple (pixbuf, width, height, GDK_INTERP_BILINEAR);
+    if (scaled) {
+	g_object_unref (pixbuf);
+	pixbuf = scaled;
+    }
+
     gtk_image_set_from_pixbuf (GTK_IMAGE (GTK_BIN (self)->child), pixbuf);
     g_object_unref (pixbuf);
 
@@ -489,9 +496,24 @@ open_drive (DriveButton *self, GtkWidget *item)
 
     screen = gtk_widget_get_screen (GTK_WIDGET (self));
 
-    if (self->drive)
+    if (self->drive) {
 	argv[1] = gnome_vfs_drive_get_activation_uri (self->drive);
-    else if (self->volume)
+	/* if the drive has no activation URI, get the activation URI
+	 * of it's first mounted volume */
+	if (!argv[1]) {
+	    GList *volumes;
+	    GnomeVFSVolume *volume;
+
+	    volumes = gnome_vfs_drive_get_mounted_volumes (self->drive);
+	    if (volumes) {
+		volume = GNOME_VFS_VOLUME (volumes->data);
+
+		argv[1] = gnome_vfs_volume_get_activation_uri (volume);
+		g_list_foreach (volumes, (GFunc)gnome_vfs_volume_unref, NULL);
+		g_list_free (volumes);
+	    }
+	}
+    } else if (self->volume)
 	argv[1] = gnome_vfs_volume_get_activation_uri (self->volume);
     else
 	g_return_if_reached();
@@ -706,6 +728,7 @@ check_audio_cd (DriveButton *self, GnomeVFSVolume *volume)
 static void
 run_command (DriveButton *self, const char *command)
 {
+	char *uri, *mount_path;
 	char *device_path = gnome_vfs_drive_get_device_path (self->drive);
 
 	GList *volumes;
@@ -713,8 +736,8 @@ run_command (DriveButton *self, const char *command)
 
 	volumes = gnome_vfs_drive_get_mounted_volumes (self->drive);
 	volume = GNOME_VFS_VOLUME (volumes->data);
-	char *uri = gnome_vfs_volume_get_activation_uri (volume);
-	char *mount_path = gnome_vfs_get_local_path_from_uri (uri);
+	uri = gnome_vfs_volume_get_activation_uri (volume);
+	mount_path = gnome_vfs_get_local_path_from_uri (uri);
 	g_free (uri);
 
 	gnome_vfs_drive_get_display_name (self->drive);
@@ -756,10 +779,10 @@ eject_drive (DriveButton *self, GtkWidget *item)
 {
     if (self->drive) {
 	gnome_vfs_drive_eject (self->drive, mount_result,
-			       GINT_TO_POINTER(CMD_UNMOUNT));
+			       GINT_TO_POINTER(CMD_EJECT));
     } else if (self->volume) {
 	gnome_vfs_volume_eject (self->volume, mount_result,
-				GINT_TO_POINTER(CMD_UNMOUNT));
+				GINT_TO_POINTER(CMD_EJECT));
     } else {
 	g_return_if_reached();
     }
@@ -792,54 +815,45 @@ drive_button_ensure_popup (DriveButton *self)
 {
     GnomeVFSDeviceType device_type;
     char *display_name, *tmp, *label;
-    int action;
+    int action = CMD_NONE;
     GtkWidget *item;
+    GCallback callback;
+    const char *action_icon;
+    gboolean ejectable;
 
     if (self->popup_menu) return;
 
     if (self->drive) {
+	GnomeVFSVolume *volume = NULL;
+	GList *volumes;
+
 	if (!gnome_vfs_drive_is_connected (self->drive)) return;
 
 	device_type = gnome_vfs_drive_get_device_type (self->drive);
 	display_name = gnome_vfs_drive_get_display_name (self->drive);
-	if (gnome_vfs_drive_is_mounted (self->drive)) {
-	    switch (device_type) {
-	    case GNOME_VFS_DEVICE_TYPE_CDROM:
-	    case GNOME_VFS_DEVICE_TYPE_ZIP:
-	    case GNOME_VFS_DEVICE_TYPE_JAZ:
-		action = CMD_EJECT;
-		break;
-	    default:
-		action = CMD_UNMOUNT;
-	    }
-	} else {
-	    action = CMD_MOUNT_OR_PLAY;
-	}
-    } else {
-	if (!gnome_vfs_volume_is_mounted (self->volume)) return;
 
-	device_type = gnome_vfs_volume_get_device_type (self->volume);
-	display_name = gnome_vfs_volume_get_display_name (self->volume);
 	switch (device_type) {
 	case GNOME_VFS_DEVICE_TYPE_CDROM:
 	case GNOME_VFS_DEVICE_TYPE_ZIP:
 	case GNOME_VFS_DEVICE_TYPE_JAZ:
-	    action = CMD_EJECT;
+	    ejectable = TRUE;
 	    break;
 	default:
-	    action = CMD_UNMOUNT;
+	    ejectable = FALSE;
 	}
-    }
-
-	GList *volumes;
-	GnomeVFSVolume *volume = NULL;
-	GnomeVFSDeviceType volume_type = device_type;
 
+	if (gnome_vfs_drive_is_mounted (self->drive)) {
+	    if (!ejectable)
+		action = CMD_UNMOUNT;
+	} else {
+	    action = CMD_MOUNT_OR_PLAY;
+	}
+    
 	volumes = gnome_vfs_drive_get_mounted_volumes (self->drive);
 	if (volumes != NULL)
 	{
 		volume = GNOME_VFS_VOLUME (volumes->data);
-		volume_type = gnome_vfs_volume_get_device_type (volume);
+		device_type = gnome_vfs_volume_get_device_type (volume);
 	}
 
 	/*
@@ -852,16 +866,32 @@ drive_button_ensure_popup (DriveButton *self)
 	{
 		if (check_dvd_video (volume))
 		{
-			volume_type = GNOME_VFS_DEVICE_TYPE_VIDEO_DVD;
+			device_type = GNOME_VFS_DEVICE_TYPE_VIDEO_DVD;
 		}
 		if (check_audio_cd (self, volume))
 		{
-			volume_type = GNOME_VFS_DEVICE_TYPE_AUDIO_CD;
+			device_type = GNOME_VFS_DEVICE_TYPE_AUDIO_CD;
 		}
 	}
 
 	g_list_foreach (volumes, (GFunc)gnome_vfs_volume_unref, NULL);
 	g_list_free (volumes);
+    } else {
+	if (!gnome_vfs_volume_is_mounted (self->volume)) return;
+
+	device_type = gnome_vfs_volume_get_device_type (self->volume);
+	display_name = gnome_vfs_volume_get_display_name (self->volume);
+	switch (device_type) {
+	case GNOME_VFS_DEVICE_TYPE_CDROM:
+	case GNOME_VFS_DEVICE_TYPE_ZIP:
+	case GNOME_VFS_DEVICE_TYPE_JAZ:
+	    ejectable = TRUE;
+	    break;
+	default:
+	    ejectable = FALSE;
+	    action = CMD_UNMOUNT;
+	}
+    }
 
     self->popup_menu = gtk_menu_new ();
 
@@ -870,10 +900,10 @@ drive_button_ensure_popup (DriveButton *self)
     g_free (display_name);
     display_name = tmp;
 
-	GCallback callback = G_CALLBACK (open_drive);
-	const char *action_icon = GTK_STOCK_OPEN;
+	callback = G_CALLBACK (open_drive);
+	action_icon = GTK_STOCK_OPEN;
 
-	switch (volume_type) {
+	switch (device_type) {
 	case GNOME_VFS_DEVICE_TYPE_VIDEO_DVD:
 		label = g_strdup (_("_Play DVD"));
 		callback = G_CALLBACK (play_dvd);
@@ -909,13 +939,17 @@ drive_button_ensure_popup (DriveButton *self)
 	g_free (label);
 	gtk_container_add (GTK_CONTAINER (self->popup_menu), item);
 	break;
-    case CMD_EJECT:
+    default:
+	break;
+    }
+
+    if (ejectable)
+    {
 	label = g_strdup_printf (_("_Eject %s"), display_name);
 	item = create_menu_item (self, NULL, label,
 				 G_CALLBACK (eject_drive), TRUE);
 	g_free (label);
 	gtk_container_add (GTK_CONTAINER (self->popup_menu), item);
-	break;
     }
 
     g_free (display_name);
