@@ -83,7 +83,7 @@ GetLoad (int Maximum, int data [5], LoadGraph *g)
     nice = rint (Maximum * (float)(nice) / total);
     sys  = rint (Maximum * (float)(sys)  / total);
     iowait = rint (Maximum * (float)(iowait) / total);
-    free = rint (Maximum * (float)(free) / total);
+    free = Maximum - usr - nice - sys - iowait;
 
     data [0] = usr;
     data [1] = sys;
@@ -120,6 +120,12 @@ GetDiskLoad (int Maximum, int data [3], LoadGraph *g)
 	for (i = 0; i < mountlist.number; i++)
 	{
 		glibtop_fsusage fsusage;
+
+		if (strcmp(mountentries[i].type, "smbfs") == 0
+		    || strcmp(mountentries[i].type, "nfs") == 0
+		    || strcmp(mountentries[i].type, "cifs") == 0)
+			continue;
+
 		glibtop_get_fsusage(&fsusage, mountentries[i].mountdir);
 		read += fsusage.read; write += fsusage.write;
 	}
@@ -237,7 +243,7 @@ GetSwap (int Maximum, int data [2], LoadGraph *g)
     }
 
     data [0] = used;
-    data [1] = free;
+    data [1] = Maximum - used;
 }
 
 void
@@ -259,7 +265,7 @@ GetLoadAvg (int Maximum, int data [2], LoadGraph *g)
     free    = (max_loadavg - loadavg1) / max_loadavg;
 
     data [0] = rint ((float) Maximum * used);
-    data [1] = rint ((float) Maximum * free);
+    data [1] = Maximum - data[0];
 }
 
 
